@@ -414,7 +414,7 @@ Permedia2UseHWCursor(ScreenPtr pScr, CursorPtr pCurs)
 Bool 
 Permedia2HWCursorInit(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     GLINTPtr pGlint = GLINTPTR(pScrn);
     xf86CursorInfoPtr infoPtr;
 
@@ -458,7 +458,8 @@ Permedia2I2CPutBits(I2CBusPtr b, int scl, int sda)
 {
     GLINTPtr pGlint = (GLINTPtr) b->DriverPrivate.ptr;
     int r = (pGlint->DDCBus == b) ? PMDDCData : VSSerialBusControl;
-    CARD32 v = GLINT_READ_REG(r) & ~(ClkOut | DataOut);
+
+    CARD32 v = 0;
 
     if (scl > 0) v |= ClkOut;
     if (sda > 0) v |= DataOut;
